
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::SuggestionsController < ApplicationController
  include ::Paginator

  before_action :set_suggestion, only: [:show, :update, :destroy]

  # GET v1/suggestions
  def index
    suggestions= paginate Suggestion
    render json: suggestions
  end

  # GET v1/suggestions/1
  def show
    render json: @suggestion
  end

  # POST v1/suggestions
  def create
    @suggestion = Suggestion.new(suggestion_params)

    if @suggestion.save
      SuggestionsMailer.new_suggestion_received(@suggestion).deliver_now
      render json: @suggestion, status: :created
    else
      render json: @suggestion.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT v1/suggestions/1
  def update
    if @suggestion.update(suggestion_params)
      SuggestionsMailer.suggestion_updated(@suggestion).deliver_now
      render json: @suggestion
    else
      render json: @suggestion.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/suggestions/1
  def destroy
    @suggestion.destroy
    render status: :ok
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_suggestion
      @suggestion = Suggestion.where(id: params[:id]).first

      render status: :not_found if @suggestion.blank?

      @suggestion
    end

    # Only allow a trusted parameter "white list" through.
    def suggestion_params
      params.require(:suggestion).permit(:name, :link, :description, :status)
    end
end
